<?php
namespace Ep\WooCommerce;

use Ep\WordPress\Service\AbstractWordPressService;
use Zend\Validator\ValidatorInterface;
use Zend\Validator\ValidatorPluginManager;

/**
 * Class RegistrationService
 *
 * @package Ep\WooCommerce
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class RegistrationService extends AbstractWordPressService
{
	public function attach(): void
	{
		$recaptchaConfig = $this->services->get('config')['recaptcha'];

		if ('1' === $recaptchaConfig['enabled']) {
			add_filter('woocommerce_process_registration_errors', [$this, 'validateRegistration'], 10, 1);
		}
	}

	public function validateRegistration(\WP_Error $error)
	{
		/** @var ValidatorPluginManager $validators */
		$validators = $this->services->get('ValidatorManager');
		/** @var ValidatorInterface $validator */
		$validator = $validators->get('recaptcha');

		if (!$validator->isValid($_POST['g-recaptcha-response'] ?? '')) {
			$error->add('recaptcha', implode("\n", $validator->getMessages()));
		}

		return $error;
	}
}